package
Version:
v0.0.0-...-a01399d
Opens a new window with list of versions in this module.
Published: Jul 3, 2022
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Config struct {
FilePath string `envconfig:"FILE_PATH"`
Addr string `envconfig:"SRV_ADDR"`
Port1 int `envconfig:"SRV_PORT1"`
Port2 int `envconfig:"SRV_PORT2"`
}
NewConfig reads config from environment.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.