package
Version:
v0.0.0-...-a01399d
Opens a new window with list of versions in this module.
Published: Jul 3, 2022
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type File struct {
Filename string `json:"filename" validate:"required"`
}
type WriteRequest struct {
Raw string `json:"raw" validate:"required"`
Key string `json:"key" validate:"required"`
TimeStamp int64 `json:"-"`
ClientName string `json:"-"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.